/v1/projects/{project_id}/iou/vms/{vm_id} — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Iou »

# /v1/projects/{project_id}/iou/vms/{vm_id}

Contents

- /v1/projects/{project_id}/iou/vms/{vm_id}
  - GET /v1/projects/{project_id}/iou/vms/{vm_id}
    - Parameters
    - Response status codes
    - Output
    - Sample session
  - PUT /v1/projects/{project_id}/iou/vms/{vm_id}
    - Parameters
    - Response status codes
    - Input
    - Output
    - Sample session
  - DELETE /v1/projects/{project_id}/iou/vms/{vm_id}
    - Parameters
    - Response status codes
    - Sample session

## GET /v1/projects/{project_id}/iou/vms/{vm_id}

Get a IOU instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 200: Success
- 400: Invalid request
- 404: Instance doesn’t exist

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
ethernet_adapters | ✔ | integer | How many ethernet adapters are connected to the IOU
initial_config | ✔ | ['string', 'null'] | Path of the initial config content relative to project directory
l1_keepalives | ✔ | boolean | Always up ethernet interface
name | ✔ | string | IOU VM name
nvram | ✔ | integer | Allocated NVRAM KB
path | ✔ | string | Path of iou binary
project_id | ✔ | string | Project UUID
ram | ✔ | integer | Allocated RAM MB
serial_adapters | ✔ | integer | How many serial adapters are connected to the IOU
vm_id | ✔ | string | IOU VM UUID

### Sample session

    curl -i -X GET 'http://localhost:8000/projects/{project_id}/iou/vms/{vm_id}'

    GET /projects/{project_id}/iou/vms/{vm_id} HTTP/1.1

    HTTP/1.1 200
    CONNECTION: keep-alive
    CONTENT-LENGTH: 409
    CONTENT-TYPE: application/json
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/projects/{project_id}/iou/vms/{vm_id}

    {
        "console": 2000,
        "ethernet_adapters": 2,
        "initial_config": null,
        "l1_keepalives": false,
        "name": "PC TEST 1",
        "nvram": 128,
        "path": "/private/var/folders/3s/r2wbv07n7wg4vrsn874lmxxh0000gn/T/pytest-3621/test_iou_get0/iou.bin",
        "project_id": "a1e920ca-338a-4e9f-b363-aa607b09dd80",
        "ram": 256,
        "serial_adapters": 2,
        "vm_id": "f75ff9e7-e658-45f7-9021-1651cfed1194"
    }

## PUT /v1/projects/{project_id}/iou/vms/{vm_id}

Update a IOU instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 200: Instance updated
- 400: Invalid request
- 404: Instance doesn’t exist
- 409: Conflict

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
console |  | ['integer', 'null'] | console TCP port
ethernet_adapters |  | ['integer', 'null'] | How many ethernet adapters are connected to the IOU
initial_config_content |  | ['string', 'null'] | Initial configuration of the IOU
l1_keepalives |  | ['boolean', 'null'] | Always up ethernet interface
name |  | ['string', 'null'] | IOU VM name
nvram |  | ['integer', 'null'] | Allocated NVRAM KB
path |  | ['string', 'null'] | Path of iou binary
ram |  | ['integer', 'null'] | Allocated RAM MB
serial_adapters |  | ['integer', 'null'] | How many serial adapters are connected to the IOU

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
ethernet_adapters | ✔ | integer | How many ethernet adapters are connected to the IOU
initial_config | ✔ | ['string', 'null'] | Path of the initial config content relative to project directory
l1_keepalives | ✔ | boolean | Always up ethernet interface
name | ✔ | string | IOU VM name
nvram | ✔ | integer | Allocated NVRAM KB
path | ✔ | string | Path of iou binary
project_id | ✔ | string | Project UUID
ram | ✔ | integer | Allocated RAM MB
serial_adapters | ✔ | integer | How many serial adapters are connected to the IOU
vm_id | ✔ | string | IOU VM UUID

### Sample session

    curl -i -X PUT 'http://localhost:8000/projects/{project_id}/iou/vms/{vm_id}' -d '{"console": 2001, "ethernet_adapters": 4, "initial_config_content": "hostname test", "l1_keepalives": true, "name": "test", "nvram": 2048, "ram": 512, "serial_adapters": 0}'

    PUT /projects/{project_id}/iou/vms/{vm_id} HTTP/1.1
    {
        "console": 2001,
        "ethernet_adapters": 4,
        "initial_config_content": "hostname test",
        "l1_keepalives": true,
        "name": "test",
        "nvram": 2048,
        "ram": 512,
        "serial_adapters": 0
    }

    HTTP/1.1 200
    CONNECTION: keep-alive
    CONTENT-LENGTH: 423
    CONTENT-TYPE: application/json
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/projects/{project_id}/iou/vms/{vm_id}

    {
        "console": 2001,
        "ethernet_adapters": 4,
        "initial_config": "initial-config.cfg",
        "l1_keepalives": true,
        "name": "test",
        "nvram": 2048,
        "path": "/private/var/folders/3s/r2wbv07n7wg4vrsn874lmxxh0000gn/T/pytest-3621/test_iou_update0/iou.bin",
        "project_id": "a1e920ca-338a-4e9f-b363-aa607b09dd80",
        "ram": 512,
        "serial_adapters": 0,
        "vm_id": "e867af73-aaf1-4770-a935-78a357ea5db3"
    }

## DELETE /v1/projects/{project_id}/iou/vms/{vm_id}

Delete a IOU instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 400: Invalid request
- 404: Instance doesn’t exist
- 204: Instance deleted

### Sample session

    curl -i -X DELETE 'http://localhost:8000/projects/{project_id}/iou/vms/{vm_id}'

    DELETE /projects/{project_id}/iou/vms/{vm_id} HTTP/1.1

    HTTP/1.1 204
    CONNECTION: keep-alive
    CONTENT-LENGTH: 0
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/projects/{project_id}/iou/vms/{vm_id}

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Iou »